@@ -5,7 +5,7 @@ try:
 except ImportError:
     raise RuntimeError("Please use pretix 2.7 or above to run this plugin!")
 
-__version__ = '0.1.0'
+__version__ = '0.2.0'
 
 
 class PluginApp(PluginConfig):
@@ -13,7 +13,7 @@ class PluginApp(PluginConfig):
     verbose_name = 'Bambora Payform'
 
     class PretixPluginMeta:
-        name = gettext_lazy('Bambora Payform')
+        name = 'Bambora Payform'
         author = 'Jaakko Rinta-Filppula'
         description = gettext_lazy('Payment plugin for Bambora Payform')
         visible = True
